# <span style="font-family:Papyrus; font-size:35px;"><span style="color: rgb(112,156,96);">**E**</span>nvironmental <span style="color: rgb(140,201,200);">**D**</span>ata <span style="color: rgb(245,74,57);">**A**</span>cquisition <span style="color: rgb(21,97,101);">**M**</span>odule</span>

EDAM (Environmental Data Acquisition Module), is a template framework that
facilitates
timeseries data acquisition and integration. EDAM templates are written using
programming
language-agnostic semantics, and can be reused both for input and output, thus
enabling
data reuse via transformations across different formats.

The theoretical concepts on which EDAM is based are documented 
in the Open Access paper: 
"[A template framework for environmental timeseries data acquisition](https://www.sciencedirect.com/science/article/pii/S1364815218302627)"

# Table of contents

- [Installation](installation)
- [EDAM template language](edam-template-language/metadata.md#metadata-file)
- [Proposed workflow](workflow.md#proposed-workflow)
- [Test cases](test-cases)
    - [AgMIP and APSIM](test-cases/agmip_apsim.md#agmip-and-apsim-weather-data-files)
    - [AgMIP data files](test-cases/agmip.md#agmip-data-files)
    - [APSIM station](test-cases/apsim.md#apsim-station)
    - [UK Meteorological Office](test-cases/uk_met.md#uk-meteorological-office)